============
OSC-recorder
============


.. image:: https://img.shields.io/pypi/v/osc_recorder.svg
        :target: https://pypi.python.org/pypi/osc_recorder

.. .. image:: https://img.shields.io/travis/oishefarhan/OSC-recorder.svg
..         :target: https://travis-ci.org/oishefarhan/OSC-recorder

.. image:: https://readthedocs.org/projects/osc-recorder/badge/?version=latest
        :target: https://osc-recorder.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


Python scripts to capture and replay OSC packets. Built on top of pyliblo.

Documentation: https://osc-recorder.readthedocs.io.

Installation
------------
* Download and install liblo_ first
  * For Mac OSX :code:`brew install liblo`
* Install pyliblo: :code:`pip install pyliblo`
* If it doesn't work, follow instructions here: pyliblo_

If you want to install from source.

Clone the repo and run :code:`pip install .` from the folder.


.. _liblo: http://liblo.sourceforge.net/
.. _pyliblo: http://das.nasophon.de/pyliblo/


TODO
----
* Fix sphinx autodoc for modules


Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
